tietools.iterate_topmost_masked_tie_chains_and_containers_in_expr
=================================================================

.. autofunction:: abjad.tools.tietools.iterate_topmost_masked_tie_chains_and_containers_in_expr.iterate_topmost_masked_tie_chains_and_containers_in_expr
   :noindex:
